@@ -1,5 +1,4 @@
-
-__version__ = '0.3.21'
+__version__ = "0.3.28"
 
 from .animal import HIPPO
 from .compound import Compound, Ingredient
@@ -18,4 +17,5 @@ from .rgen import RandomRecipeGenerator
 from .rset import ReactionTable, ReactionSet
 from .tags import TagTable, TagSet
 from .target import Target
-# from .scoring import Scorer, CustomAttribute
+from .scoring import Scorer, CustomAttribute
+from .web import ProjectPage
